Microformats2 parsed from HTML, or from the Hiccup of html-pieces, by the microformats2 parsing specification: https://microformats.org/wiki/microformats2-parsing
The functions after parse read its result: the microformats of a page in document order, the values of their properties, the representative h-card of a page, and the author of an h-entry.
Microformats2 parsed from HTML, or from the Hiccup of html-pieces, by the microformats2 parsing specification: https://microformats.org/wiki/microformats2-parsing The functions after parse read its result: the microformats of a page in document order, the values of their properties, the representative h-card of a page, and the author of an h-entry.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |